@@ -141,6 +141,7 @@ from .base_coupon import BaseCoupon
 from .base_directory import BaseDirectory
 from .base_error import BaseError
 from .base_file import BaseFile
+from .base_lms_capabilities import BaseLMSCapabilities
 from .base_lti1p1_provider import BaseLTI1p1Provider
 from .base_lti1p3_provider import BaseLTI1p3Provider
 from .base_lti_provider import BaseLTIProvider
@@ -202,6 +203,9 @@ from .course_registration_link import CourseRegistrationLink
 from .course_role import CourseRole
 from .course_role_as_json_with_perms import CourseRoleAsJSONWithPerms
 from .course_section import CourseSection
+from .course_section_division import CourseSectionDivision
+from .course_section_division_connection import CourseSectionDivisionConnection
+from .course_section_division_user import CourseSectionDivisionUser
 from .course_snippet import CourseSnippet
 from .course_state import CourseState
 from .course_statistics_as_json import CourseStatisticsAsJSON
@@ -210,6 +214,7 @@ from .create_auto_test_data import CreateAutoTestData
 from .create_comment_data import CreateCommentData
 from .create_comment_reply_data import CreateCommentReplyData
 from .create_course_data import CreateCourseData
+from .create_division_section_data import CreateDivisionSectionData
 from .create_group_group_set_data import CreateGroupGroupSetData
 from .create_group_set_course_data import CreateGroupSetCourseData
 from .create_lti_data import CreateLTIData
@@ -239,6 +244,9 @@ from .deleted_comment_reply import DeletedCommentReply
 from .deletion_type import DeletionType
 from .directory_with_children import DirectoryWithChildren
 from .disabled_setting_exception import DisabledSettingException
+from .editor_enabled_for_teachers_setting import (
+    EditorEnabledForTeachersSetting,
+)
 from .editor_enabled_setting import EditorEnabledSetting
 from .email_notification_types import EmailNotificationTypes
 from .email_students_enabled_setting import EmailStudentsEnabledSetting
@@ -521,6 +529,9 @@ from .reset_token_time_setting import ResetTokenTimeSetting
 from .result_data_get_auto_test_get import ResultDataGetAutoTestGet
 from .result_data_get_task_result_get_all import ResultDataGetTaskResultGetAll
 from .result_data_post_login_link_login import ResultDataPostLoginLinkLogin
+from .result_data_post_section_create_division import (
+    ResultDataPostSectionCreateDivision,
+)
 from .result_data_post_user_login import ResultDataPostUserLogin
 from .result_data_post_user_register import ResultDataPostUserRegister
 from .role_as_json_with_perms import RoleAsJSONWithPerms
@@ -577,6 +588,9 @@ from .tenant_permissions import TenantPermissions
 from .tenant_price import TenantPrice
 from .tenant_role_as_json_with_perms import TenantRoleAsJSONWithPerms
 from .tenant_statistics import TenantStatistics
+from .test_submission_copying_on_import_enabled_setting import (
+    TestSubmissionCopyingOnImportEnabledSetting,
+)
 from .tour_configurations_setting import TourConfigurationsSetting
 from .tour_polling_interval_setting import TourPollingIntervalSetting
 from .transaction import Transaction
