@@ -264,6 +264,13 @@ class CoursePermMap:
     can_view_new_autotest_hidden_step_results: "bool"
     #: Users with this permission can see the AutoTest 2.0 hidden step output.
     can_view_new_autotest_hidden_step_output: "bool"
+    #: With this permission the user is allowed to always use all of the
+    #: possible submit methods. For instance, when File Uploader is disabled,
+    #: this permission can be used to overwrite and allow to upload test
+    #: submissions. Or it can be used for the teacher to inspect how the editor
+    #: would look like as an experiment, without having to enable it for the
+    #: students.
+    can_always_use_all_upload_types: "bool"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -951,6 +958,19 @@ class CoursePermMap:
                     " hidden step output."
                 ),
             ),
+            rqa.RequiredArgument(
+                "can_always_use_all_upload_types",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "With this permission the user is allowed to always use"
+                    " all of the possible submit methods. For instance, when"
+                    " File Uploader is disabled, this permission can be used"
+                    " to overwrite and allow to upload test submissions. Or it"
+                    " can be used for the teacher to inspect how the editor"
+                    " would look like as an experiment, without having to"
+                    " enable it for the students."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -1107,6 +1127,9 @@ class CoursePermMap:
             "can_view_new_autotest_hidden_step_output": to_dict(
                 self.can_view_new_autotest_hidden_step_output
             ),
+            "can_always_use_all_upload_types": to_dict(
+                self.can_always_use_all_upload_types
+            ),
         }
         return res
 
@@ -1198,6 +1221,7 @@ class CoursePermMap:
             can_view_new_autotest_hidden_step_configuration=parsed.can_view_new_autotest_hidden_step_configuration,
             can_view_new_autotest_hidden_step_results=parsed.can_view_new_autotest_hidden_step_results,
             can_view_new_autotest_hidden_step_output=parsed.can_view_new_autotest_hidden_step_output,
+            can_always_use_all_upload_types=parsed.can_always_use_all_upload_types,
         )
         res.raw_data = d
         return res
