@@ -2,6 +2,7 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+
 import datetime
 import typing as t
 from dataclasses import dataclass, field
@@ -77,3 +78,11 @@ class CustomOutputLogBase(AutoTestStepLogBase):
         )
         res.raw_data = d
         return res
+
+
+import os
+
+if os.getenv("CG_GENERATING_DOCS", "False").lower() in ("", "true"):
+    # fmt: off
+    pass
+    # fmt: on
