@@ -235,6 +235,10 @@ class FrontendSiteSettings:
     #: Should course id form Canvas be copied through LTI(1.3), and stored in
     #: our database or not.
     canvas_course_id_copying_enabled: "bool"
+    #: Can teacher edit their students' work through the code editor.
+    editor_enabled_for_teachers: "bool"
+    #: Whether the test submission is copied over when importing an assignment.
+    test_submission_copying_on_import_enabled: "bool"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -808,6 +812,22 @@ class FrontendSiteSettings:
                     " and stored in our database or not."
                 ),
             ),
+            rqa.RequiredArgument(
+                "EDITOR_ENABLED_FOR_TEACHERS",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Can teacher edit their students' work through the code"
+                    " editor."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "TEST_SUBMISSION_COPYING_ON_IMPORT_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether the test submission is copied over when importing"
+                    " an assignment."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -969,6 +989,12 @@ class FrontendSiteSettings:
             "CANVAS_COURSE_ID_COPYING_ENABLED": to_dict(
                 self.canvas_course_id_copying_enabled
             ),
+            "EDITOR_ENABLED_FOR_TEACHERS": to_dict(
+                self.editor_enabled_for_teachers
+            ),
+            "TEST_SUBMISSION_COPYING_ON_IMPORT_ENABLED": to_dict(
+                self.test_submission_copying_on_import_enabled
+            ),
         }
         return res
 
@@ -1051,6 +1077,8 @@ class FrontendSiteSettings:
             assignment_grading_scale_points_enabled=parsed.ASSIGNMENT_GRADING_SCALE_POINTS_ENABLED,
             new_auto_test_old_submission_age=parsed.NEW_AUTO_TEST_OLD_SUBMISSION_AGE,
             canvas_course_id_copying_enabled=parsed.CANVAS_COURSE_ID_COPYING_ENABLED,
+            editor_enabled_for_teachers=parsed.EDITOR_ENABLED_FOR_TEACHERS,
+            test_submission_copying_on_import_enabled=parsed.TEST_SUBMISSION_COPYING_ON_IMPORT_ENABLED,
         )
         res.raw_data = d
         return res
