@@ -329,6 +329,10 @@ class PartialAllSiteSettings:
     #: Should course id form Canvas be copied through LTI(1.3), and stored in
     #: our database or not.
     canvas_course_id_copying_enabled: Maybe["bool"] = Nothing
+    #: Can teacher edit their students' work through the code editor.
+    editor_enabled_for_teachers: Maybe["bool"] = Nothing
+    #: Whether the test submission is copied over when importing an assignment.
+    test_submission_copying_on_import_enabled: Maybe["bool"] = Nothing
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -1144,6 +1148,22 @@ class PartialAllSiteSettings:
                     " and stored in our database or not."
                 ),
             ),
+            rqa.OptionalArgument(
+                "EDITOR_ENABLED_FOR_TEACHERS",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Can teacher edit their students' work through the code"
+                    " editor."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "TEST_SUBMISSION_COPYING_ON_IMPORT_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether the test submission is copied over when importing"
+                    " an assignment."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -1425,6 +1445,12 @@ class PartialAllSiteSettings:
         self.canvas_course_id_copying_enabled = maybe_from_nullable(
             self.canvas_course_id_copying_enabled
         )
+        self.editor_enabled_for_teachers = maybe_from_nullable(
+            self.editor_enabled_for_teachers
+        )
+        self.test_submission_copying_on_import_enabled = maybe_from_nullable(
+            self.test_submission_copying_on_import_enabled
+        )
 
     def to_dict(self) -> t.Dict[str, t.Any]:
         res: t.Dict[str, t.Any] = {}
@@ -1802,6 +1828,14 @@ class PartialAllSiteSettings:
             res["CANVAS_COURSE_ID_COPYING_ENABLED"] = to_dict(
                 self.canvas_course_id_copying_enabled.value
             )
+        if self.editor_enabled_for_teachers.is_just:
+            res["EDITOR_ENABLED_FOR_TEACHERS"] = to_dict(
+                self.editor_enabled_for_teachers.value
+            )
+        if self.test_submission_copying_on_import_enabled.is_just:
+            res["TEST_SUBMISSION_COPYING_ON_IMPORT_ENABLED"] = to_dict(
+                self.test_submission_copying_on_import_enabled.value
+            )
         return res
 
     @classmethod
@@ -1911,6 +1945,8 @@ class PartialAllSiteSettings:
             assignment_grading_scale_points_enabled=parsed.ASSIGNMENT_GRADING_SCALE_POINTS_ENABLED,
             new_auto_test_old_submission_age=parsed.NEW_AUTO_TEST_OLD_SUBMISSION_AGE,
             canvas_course_id_copying_enabled=parsed.CANVAS_COURSE_ID_COPYING_ENABLED,
+            editor_enabled_for_teachers=parsed.EDITOR_ENABLED_FOR_TEACHERS,
+            test_submission_copying_on_import_enabled=parsed.TEST_SUBMISSION_COPYING_ON_IMPORT_ENABLED,
         )
         res.raw_data = d
         return res
