@@ -93,6 +93,9 @@ from .course_gradebook_render_warning_size_setting import (
 from .course_register_enabled_setting import CourseRegisterEnabledSetting
 from .csv_large_file_limit_setting import CsvLargeFileLimitSetting
 from .csv_too_many_errors_limit_setting import CsvTooManyErrorsLimitSetting
+from .editor_enabled_for_teachers_setting import (
+    EditorEnabledForTeachersSetting,
+)
 from .editor_enabled_setting import EditorEnabledSetting
 from .email_students_enabled_setting import EmailStudentsEnabledSetting
 from .exam_login_max_length_setting import ExamLoginMaxLengthSetting
@@ -204,6 +207,9 @@ from .sso_username_decollision_enabled_setting import (
     SsoUsernameDecollisionEnabledSetting,
 )
 from .student_payment_enabled_setting import StudentPaymentEnabledSetting
+from .test_submission_copying_on_import_enabled_setting import (
+    TestSubmissionCopyingOnImportEnabledSetting,
+)
 from .tour_configurations_setting import TourConfigurationsSetting
 from .tour_polling_interval_setting import TourPollingIntervalSetting
 
@@ -308,6 +314,8 @@ SiteSettingInput = t.Union[
     AssignmentGradingScalePointsEnabledSetting,
     NewAutoTestOldSubmissionAgeSetting,
     CanvasCourseIdCopyingEnabledSetting,
+    EditorEnabledForTeachersSetting,
+    TestSubmissionCopyingOnImportEnabledSetting,
 ]
 SiteSettingInputParser = rqa.Lazy(
     lambda: make_union(
@@ -411,5 +419,7 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(AssignmentGradingScalePointsEnabledSetting),
         ParserFor.make(NewAutoTestOldSubmissionAgeSetting),
         ParserFor.make(CanvasCourseIdCopyingEnabledSetting),
+        ParserFor.make(EditorEnabledForTeachersSetting),
+        ParserFor.make(TestSubmissionCopyingOnImportEnabledSetting),
     ),
 )
